@@ -1,6 +1,11 @@
 # Skip tests if gbm is not installed
 testthat::skip_if_not_installed("glmnet")
 
+# To pass the noLD checks
+eps <- if (capabilities("long.double"))
+    sqrt(.Machine$double.eps) else
+        0.1
+
 # Create data----
 n <- 100
 alp <- 0.05
@@ -117,10 +122,10 @@ test_that("output probabilities", {
     riskDT_glmnet <- absoluteRisk(fitDT_glmnet, time = 0.5, newdata = newDT_ext,
                                   family = "glmnet")
 
-    expect_true(all(riskDF_glmnet >= 0))
-    expect_true(all(riskDT_glmnet >= 0))
-    expect_true(all(riskDF_glmnet <= 1))
-    expect_true(all(riskDT_glmnet <= 1))
+    expect_true(all(riskDF_glmnet >= 0 - eps))
+    expect_true(all(riskDT_glmnet >= 0 - eps))
+    expect_true(all(riskDF_glmnet <= 1 + eps))
+    expect_true(all(riskDT_glmnet <= 1 + eps))
 })
 
 # Matrix interface----
@@ -188,10 +193,10 @@ test_that("no error in absoluteRisk with glmnet", {
 })
 
 test_that("we get probabilities", {
-    expect_true(all(risk >= 0))
-    expect_true(all(risk <= 1))
-    expect_true(all(risk_log >= 0))
-    expect_true(all(risk_log <= 1))
+    expect_true(all(risk >= 0 - eps))
+    expect_true(all(risk <= 1 + eps))
+    expect_true(all(risk_log >= 0 - eps))
+    expect_true(all(risk_log <= 1 + eps))
 })
 
 test_that("should compute risk when time and newdata aren't provided", {
@@ -225,8 +230,8 @@ test_that("no error in absoluteRisk with glmnet", {
 })
 
 test_that("we get probabilities", {
-    expect_true(all(risk[, -1] >= 0))
-    expect_true(all(risk[, -1] <= 1))
-    expect_true(all(risk_log[, -1] >= 0))
-    expect_true(all(risk_log[, -1] <= 1))
+    expect_true(all(risk[, -1] >= 0 - eps))
+    expect_true(all(risk[, -1] <= 1 + eps))
+    expect_true(all(risk_log[, -1] >= 0 - eps))
+    expect_true(all(risk_log[, -1] <= 1 + eps))
 })
